package disks

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// ReplicationStartRequest struct to starts replication between two chosen disks
type ReplicationStartRequest struct {
	// Id of the disk to replicate. Primary disk in replication
	// Required: true
	DiskID uint64 `url:"diskId" json:"diskId" validate:"required"`

	// ID of target disk. Secondary disk in replication
	// Required: true
	TargetDiskID uint64 `url:"targetDiskId" json:"targetDiskId" validate:"required"`
}

// ReplicationStart starts replication between two chosen disks. It's required for both disks to have same size to avoid replication conflicts
// Note: Source disk's SEP and target SEP supported only of TATLIN type.
func (d Disks) ReplicationStart(ctx context.Context, req ReplicationStartRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudapi/disks/replicationStart"

	res, err := d.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
