package vfpool

import (
	"context"
	"encoding/json"
	"net/http"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// ListRequest struct to get list of vfpool devices
type ListRequest struct {
	// Find by ID
	// Required: false
	ByID uint64 `url:"by_id,omitempty" json:"by_id,omitempty"`

	// Find by Grid ID
	// Required: false
	GID uint64 `url:"gid,omitempty" json:"gid,omitempty"`

	// Find by name
	// Required: false
	Name string `url:"name,omitempty" json:"name,omitempty"`

	// Find by description
	// Required: false
	Description string `url:"description,omitempty" json:"description,omitempty"`

	// Find by status
	// Required: false
	Status string `url:"status,omitempty" json:"status,omitempty"`

	// Find by account Access
	// Required: false
	AccountAccess uint64 `url:"accountAccess,omitempty" json:"accountAccess,omitempty"`

	// Find by resource group Access
	// Required: false
	RGAccess uint64 `url:"rgAccess,omitempty" json:"rgAccess,omitempty"`

	// Sort by one of supported fields, format +|-(field)
	// Required: false
	SortBy string `url:"sortBy,omitempty" json:"sortBy,omitempty" validate:"omitempty,sortBy"`

	// Page number
	// Required: false
	Page uint64 `url:"page,omitempty" json:"page,omitempty"`

	// Page size
	// Required: false
	Size uint64 `url:"size,omitempty" json:"size,omitempty"`
}

// List gets list of all available vfpool devices as a ListVFPool struct
func (v VFPool) List(ctx context.Context, req ListRequest) (*ListVFPool, error) {

	res, err := v.ListRaw(ctx, req)
	if err != nil {
		return nil, err
	}

	list := ListVFPool{}

	err = json.Unmarshal(res, &list)
	if err != nil {
		return nil, err
	}

	return &list, nil
}

// ListRaw gets list of all available vfpool devices as an array of bytes
func (v VFPool) ListRaw(ctx context.Context, req ListRequest) ([]byte, error) {

	if err := validators.ValidateRequest(req); err != nil {
		return nil, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudapi/vfpool/list"

	res, err := v.client.DecortApiCall(ctx, http.MethodPost, url, req)
	return res, err
}
