package resmon

import (
	"context"
	"encoding/json"
	"net/http"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

type GetByStacksRequest struct {
	// Start of time period - unixtime
	// Required: false
	StartTime uint64 `url:"starttime,omitempty" json:"starttime,omitempty"`

	// End of time period - unixtime
	// Required: true
	EndTime uint64 `url:"endtime,omitempty" json:"endtime,omitempty"`
}

// Get a grid resource monitoring for the specified time period
func (r Resmon) GetByStacks(ctx context.Context, req GetByStacksRequest) (*GetByStackData, error) {
	res, err := r.GetByStacksRaw(ctx, req)
	if err != nil {
		return nil, err
	}

	info := GetByStackData{}

	err = json.Unmarshal(res, &info)
	if err != nil {
		return nil, err
	}

	return &info, nil
}

// GetRaw gets information about compute as an array of bytes
func (r Resmon) GetByStacksRaw(ctx context.Context, req GetByStacksRequest) ([]byte, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return nil, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/resmon/getByStacks"

	res, err := r.client.DecortApiCall(ctx, http.MethodPost, url, req)
	return res, err
}
