package vfpool

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// EnableRequest struct to enable vfpool device
type EnableRequest struct {
	// VFPool device ID
	// Required: true
	VFPoolID uint64 `url:"id" json:"id" validate:"required"`
}

// Enable enables vfpool device
func (v VFPool) Enable(ctx context.Context, req EnableRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/vfpool/enable"

	res, err := v.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
